#!/usr/bin/env python
##############################################################################
#
# pyobjcryst        by DANSE Diffraction group
#                   Simon J. L. Billinge
#                   (c) 2009 The Trustees of Columbia University
#                   in the City of New York.  All rights reserved.
#
# File coded by:    Chris Farrow
#
# See AUTHORS.txt for a list of people who contributed.
# See LICENSE_DANSE.txt for license information.
#
##############################################################################

"""Python wrapping of things from General.h.

See the online ObjCryst++ documentation (https://objcryst.readthedocs.io).
"""

__all__ = ["RadiationType", "ObjCrystException", "WavelengthType"]

from pyobjcryst._pyobjcryst import RadiationType, WavelengthType
from pyobjcryst._pyobjcryst import ObjCrystException
